@@ -1,7 +1,10 @@
+import heapq
+import asyncio
+
 import synapse.common as s_common
 
+import synapse.lib.coro as s_coro
 import synapse.lib.msgpack as s_msgpack
-import synapse.lib.lmdbslab as s_lmdbslab
 
 class SlabSeqn:
     '''
@@ -11,23 +14,40 @@ class SlabSeqn:
         lenv (lmdb.Environment): The LMDB Environment.
         name (str): The name of the sequence.
     '''
-    def __init__(self, slab: s_lmdbslab.Slab, name: str) -> None:
+    def __init__(self, slab, name: str) -> None:
 
         self.slab = slab
         self.db = self.slab.initdb(name)
 
         self.indx = self.nextindx()
+        self.offsevents = []  # type: ignore # List[Tuple[int, int, asyncio.Event]] as a heap
+        self._waitcounter = 0
 
-    def add(self, item):
+    def _wake_waiters(self):
+        while self.offsevents and self.offsevents[0][0] < self.indx:
+            _, _, evnt = heapq.heappop(self.offsevents)
+            evnt.set()
+
+    def add(self, item, indx=None):
         '''
         Add a single item to the sequence.
         '''
-        byts = s_msgpack.en(item)
-        lkey = s_common.int64en(self.indx)
+        if indx is not None:
+            self.slab.put(s_common.int64en(indx), s_msgpack.en(item), db=self.db)
+            if indx >= self.indx:
+                self.indx = indx + 1
+                self._wake_waiters()
+            return indx
+
+        indx = self.indx
+        self.slab.put(s_common.int64en(indx), s_msgpack.en(item), db=self.db)
 
-        self.slab.put(lkey, byts, db=self.db)
         self.indx += 1
 
+        self._wake_waiters()
+
+        return indx
+
     def last(self):
 
         last = self.slab.last(db=self.db)
@@ -75,20 +95,10 @@ class SlabSeqn:
         origindx = self.indx
         self.indx = indx
 
+        self._wake_waiters()
+
         return {'indx': indx, 'size': size, 'count': len(items), 'time': tick, 'took': took, 'orig': origindx}
 
-    def append(self, item):
-
-        byts = s_msgpack.en(item)
-
-        indx = self.indx
-        lkey = s_common.int64en(indx)
-
-        self.slab.put(lkey, byts, db=self.db)
-
-        self.indx += 1
-        return indx
-
     def index(self):
         '''
         Return the current index to be used
@@ -102,12 +112,11 @@ class SlabSeqn:
         Returns:
             int: The next insert offset.
         '''
-        indx = 0
-        with s_lmdbslab.Scan(self.slab, self.db) as curs:
-            last_key = curs.last_key()
-            if last_key is not None:
-                indx = s_common.int64un(last_key) + 1
-        return indx
+        byts = self.slab.lastkey(db=self.db)
+        if byts is None:
+            return 0
+
+        return s_common.int64un(byts) + 1
 
     def iter(self, offs):
         '''
@@ -120,12 +129,27 @@ class SlabSeqn:
             (indx, valu): The index and valu of the item.
         '''
         startkey = s_common.int64en(offs)
-
         for lkey, lval in self.slab.scanByRange(startkey, db=self.db):
             indx = s_common.int64un(lkey)
             valu = s_msgpack.un(lval)
             yield indx, valu
 
+    def trim(self, offs):
+        '''
+        Delete entries starting at offset and moving forward.
+        '''
+        retn = False
+
+        startkey = s_common.int64en(offs)
+        for lkey, _ in self.slab.scanByRange(startkey, db=self.db):
+            retn = True
+            self.slab.delete(lkey, db=self.db)
+
+        if retn:
+            self.indx = self.nextindx()
+
+        return retn
+
     def iterBack(self, offs):
         '''
         Iterate backwards over items in a sequence from a given offset.
@@ -152,6 +176,15 @@ class SlabSeqn:
             indx = s_common.int64un(lkey)
             yield indx, byts
 
+    def get(self, offs):
+        '''
+        Retrieve a single row by offset
+        '''
+        lkey = s_common.int64en(offs)
+        valu = self.slab.get(lkey, db=self.db)
+        if valu is not None:
+            return s_msgpack.un(valu)
+
     def slice(self, offs, size):
 
         imax = size - 1
@@ -178,3 +211,33 @@ class SlabSeqn:
         byts = self.slab.get(indxbyts, db=self.db)
         if byts is not None:
             return s_msgpack.un(byts)
+
+    def getOffsetEvent(self, offs):
+        '''
+        Returns an asyncio Event that will be set when the particular offset is written.  The event will be set if the
+        offset has already been reached.
+        '''
+        evnt = asyncio.Event()
+
+        if offs < self.indx:
+            evnt.set()
+            return evnt
+
+        # We add a simple counter to the tuple to cause stable (and FIFO) sorting and prevent ties
+        heapq.heappush(self.offsevents, (offs, self._waitcounter, evnt))
+
+        self._waitcounter += 1
+
+        return evnt
+
+    async def waitForOffset(self, offs, timeout=None):
+        '''
+        Returns:
+            true if the event got set, False if timed out
+        '''
+
+        if offs < self.indx:
+            return True
+
+        evnt = self.getOffsetEvent(offs)
+        return await s_coro.event_wait(evnt, timeout=timeout)
