@@ -1,6 +1,7 @@
 import asyncio
 import logging
 import argparse
+import contextlib
 import collections
 
 import synapse.exc as s_exc
@@ -15,6 +16,7 @@ import synapse.lib.scope as s_scope
 import synapse.lib.config as s_config
 import synapse.lib.scrape as s_scrape
 import synapse.lib.grammar as s_grammar
+import synapse.lib.spooled as s_spooled
 import synapse.lib.provenance as s_provenance
 import synapse.lib.stormtypes as s_stormtypes
 
@@ -516,8 +518,7 @@ stormcmds = (
         ),
         'storm': '''
             $trig = $lib.trigger.add($cmdopts)
-
-            $lib.print("Added trigger: {iden}", iden=$iden)
+            $lib.print("Added trigger: {iden}", iden=$trig.iden)
         ''',
     },
     {
@@ -1055,7 +1056,7 @@ class Runtime:
     opaque object which is called through, but not dereferenced.
 
     '''
-    def __init__(self, snap, opts=None, user=None):
+    def __init__(self, query, snap, opts=None, user=None, root=None):
 
         if opts is None:
             opts = {}
@@ -1069,6 +1070,12 @@ class Runtime:
         self.snap = snap
         self.user = user
 
+        self.root = root
+        self.funcscope = False
+
+        self.query = query
+
+        self.readonly = opts.get('readonly', False) # EXPERIMENTAL: Make it safe to run untrusted queries
         self.model = snap.core.getDataModel()
 
         self.task = asyncio.current_task()
@@ -1081,15 +1088,24 @@ class Runtime:
         if varz is not None:
             self.vars.update(varz)
 
-        self.runtvars = set()
-        self.runtvars.update(self.vars.keys())
-        self.runtvars.update(self.ctors.keys())
-        self.isModuleRunt = False
-        self.globals = set()
-        self.modulefuncs = {}
+        # declare path builtins as non-runtsafe
+        self.runtvars = {
+            'node': False,
+            'path': False,
+        }
+
+        # inherit runtsafe vars from our root
+        if self.root is not None:
+            self.runtvars.update(root.runtvars)
+
+        # all vars/ctors are de-facto runtsafe
+        self.runtvars.update({k: True for k in self.vars.keys()})
+        self.runtvars.update({k: True for k in self.ctors.keys()})
 
         self.proxies = {}
 
+        self._loadRuntVars(query)
+
     async def dyncall(self, iden, todo, gatekeys=()):
         return await self.snap.core.dyncall(iden, todo, gatekeys=gatekeys)
 
@@ -1121,9 +1137,7 @@ class Runtime:
         return prox
 
     def isRuntVar(self, name):
-        if name in self.runtvars:
-            return True
-        return False
+        return bool(self.runtvars.get(name))
 
     async def printf(self, mesg):
         return await self.snap.printf(mesg)
@@ -1131,6 +1145,9 @@ class Runtime:
     async def warn(self, mesg, **info):
         return await self.snap.warn(mesg, **info)
 
+    async def warnonce(self, mesg, **info):
+        return await self.snap.warnonce(mesg, **info)
+
     def tick(self):
         pass
 
@@ -1138,7 +1155,7 @@ class Runtime:
         self.task.cancel()
 
     def initPath(self, node):
-        return s_node.Path(self, dict(self.vars), [node])
+        return s_node.Path(dict(self.vars), [node])
 
     def getOpt(self, name, defval=None):
         return self.opts.get(name, defval)
@@ -1158,10 +1175,33 @@ class Runtime:
             self.vars[name] = item
             return item
 
+        if self.root is not None:
+            valu = self.root.getVar(name, defv=s_common.novalu)
+            if valu is not s_common.novalu:
+                return valu
+
         return defv
 
+    def _isRootScope(self, name):
+        if self.root is None:
+            return False
+        if not self.funcscope:
+            return True
+        if name in self.root.vars:
+            return True
+        return self.root._isRootScope(name)
+
     def setVar(self, name, valu):
+
+        if name in self.ctors or name in self.vars:
+            self.vars[name] = valu
+            return
+
+        if self._isRootScope(name):
+            return self.root.setVar(name, valu)
+
         self.vars[name] = valu
+        return
 
     def addInput(self, node):
         '''
@@ -1201,93 +1241,48 @@ class Runtime:
         '''
         return self.user.confirm(perms, gateiden=gateiden)
 
-    def loadRuntVars(self, query):
+    def _loadRuntVars(self, query):
         # do a quick pass to determine which vars are per-node.
         for oper in query.kids:
-            for name in oper.getRuntVars(self):
-                if self.isModuleRunt and isinstance(oper, s_ast.Function):
-                    self.modulefuncs[name] = oper
-                self.runtvars.add(name)
+            for name, isrunt in oper.getRuntVars(self):
+                # once runtsafe, always runtsafe
+                if self.runtvars.get(name):
+                    continue
+                self.runtvars[name] = isrunt
 
-    async def iterStormQuery(self, query, genr=None):
-
-        with s_provenance.claim('storm', q=query.text, user=self.user.iden):
-
-            self.loadRuntVars(query)
-
-            # init any options from the query
-            # (but dont override our own opts)
-            for name, valu in query.opts.items():
-                self.opts.setdefault(name, valu)
-
-            async for node, path in query.iterNodePaths(self, genr=genr):
+    async def execute(self, genr=None):
+        with s_provenance.claim('storm', q=self.query.text, user=self.user.iden):
+            async for item in self.query.iterNodePaths(self, genr=genr):
                 self.tick()
-                yield node, path
+                yield item
 
-    def canPropName(self, name):
-        if name not in self.modulefuncs and name not in self.ctors:
-            return True
-        return False
-
-    async def getScopeRuntime(self, query, opts=None, impd=False):
+    @contextlib.contextmanager
+    def getSubRuntime(self, query, opts=None):
         '''
-        Derive a new runt off of an existing runt. It will pass down any global level vars. It has to
-        re run the oper.run function on any function opers so that it gets the correct context of
-        variable values and functions.
+        Yield a runtime with shared scope that will populate changes upward.
         '''
-        runt = Runtime(self.snap, user=self.user, opts=opts)
-        # imported implies module level
-        runt.isModuleRunt = impd
-        if not impd:  # respect the import boundary
+        runt = Runtime(query, self.snap, user=self.user, opts=opts, root=self)
+        runt.readonly = self.readonly
 
-            # if we are a top level module we need to
-            # push down our runtvars
-            if self.isModuleRunt:
-                for name in self.runtvars:
-                    valu = self.vars.get(name, s_common.novalu)
-                    if valu is s_common.novalu:
-                        continue
-                    if self.canPropName(name):
-                        runt.globals.add(name)
-                        runt.runtvars.add(name)
-                        runt.vars[name] = valu
+        yield runt
 
-            # propagate down all the global variables
-            for name in self.globals:
-                if self.canPropName(name):
-                    runt.vars[name] = self.vars[name]
-                    runt.globals.add(name)
-                    runt.runtvars.add(name)
+    @contextlib.contextmanager
+    def getCmdRuntime(self, query, opts=None):
+        '''
+        Yield a runtime with proper scoping for use in executing a pure storm command.
+        '''
+        runt = Runtime(query, self.snap, user=self.user, opts=opts)
+        runt.readonly = self.readonly
+        yield runt
 
-            # regardless of module level, we have to reload the module functions
-            # we were given so they run with the right runt. We need this so we have
-            # the whole function telescoping going on, and module level variables get
-            # set to the right values
-            runt.modulefuncs = dict(self.modulefuncs)
-            for name, oper in self.modulefuncs.items():
-                runt.runtvars.add(name)
-                async for item in oper.run(runt, s_common.agen()):
-                    pass  # pragma: no cover
-
-        runt.loadRuntVars(query)
+    def getModRuntime(self, query, opts=None):
+        '''
+        Construct a non-context managed runtime for use in module imports.
+        '''
+        runt = Runtime(query, self.snap, user=self.user, opts=opts)
+        runt.readonly = self.readonly
         return runt
 
-    async def propBackGlobals(self, runt):
-        '''
-        From a called runt (passed in by parameter), propagate the vars we know to be global
-        to the module back up into the calling runt. *Don't* propagate any functions, since
-        those need the context of which runt they're being called from, and just for safety
-        don't mess with the base lib object.
-        '''
-        for name in runt.globals:
-            valu = runt.vars.get(name, s_common.novalu)
-            if valu is s_common.novalu:
-                continue
-            if not self.canPropName(name):
-                # don't override our parent's version of a function
-                continue
-            self.vars[name] = valu
-
 class Parser:
 
     def __init__(self, prog=None, descr=None, root=None):
@@ -1625,6 +1620,7 @@ class Cmd:
     name = 'cmd'
     pkgname = ''
     svciden = ''
+    readonly = False
     forms = {}  # type: ignore
 
     def __init__(self, runt, runtsafe):
@@ -1638,6 +1634,9 @@ class Cmd:
         self.pars = self.getArgParser()
         self.pars.printf = runt.snap.printf
 
+    def isReadOnly(self):
+        return self.readonly
+
     @classmethod
     def getCmdBrief(cls):
         return cls.__doc__.strip().split('\n')[0]
@@ -1712,6 +1711,11 @@ class Cmd:
 
 class PureCmd(Cmd):
 
+    # pure commands are all "readonly" safe because their perms are enforced
+    # by the underlying runtime executing storm operations that are readonly
+    # or not
+    readonly = True
+
     def __init__(self, cdef, runt, runtsafe):
         self.cdef = cdef
         Cmd.__init__(self, runt, runtsafe)
@@ -1733,35 +1737,23 @@ class PureCmd(Cmd):
         text = self.cdef.get('storm')
         query = runt.snap.core.getStormQuery(text)
 
+        cmdopts = s_stormtypes.CmdOpts(self)
+
         opts = {
             'vars': {
-                'cmdopts': None,
-                'cmdconf': self.cdef.get('cmdconf', {})
+                'cmdopts': cmdopts,
+                'cmdconf': self.cdef.get('cmdconf', {}),
             }
         }
-        with runt.snap.getStormRuntime(opts=opts, user=runt.user) as subr:
 
-            if self.opts is not None:
-                subr.setVar('cmdopts', vars(self.opts))
+        async def genx():
+            async for xnode, xpath in genr:
+                xpath.initframe(initvars={'cmdopts': cmdopts})
+                yield xnode, xpath
 
-            subr.setVar('cmdconf', self.cdef.get('cmdconf', {}))
-
-            async def wrapgenr():
-
-                async for node, path in genr:
-
-                    # In the event of a non-runtsafe command invocation our
-                    # setArgv() method will be called with an argv computed
-                    # for each node, so we need to remap cmdopts into our path & subr
-                    cmdopts = vars(self.opts)
-                    path.initframe(initvars={'cmdopts': cmdopts}, initrunt=subr)
-                    subr.setVar('cmdopts', cmdopts)
-                    yield node, path
-
-            subr.loadRuntVars(query)
-
-            async for node, path in subr.iterStormQuery(query, genr=wrapgenr()):
-                path.finiframe(subr)
+        with runt.getCmdRuntime(query, opts=opts) as subr:
+            async for node, path in subr.execute(genr=genx()):
+                path.finiframe()
                 yield node, path
 
 class HelpCmd(Cmd):
@@ -1838,6 +1830,7 @@ class LimitCmd(Cmd):
     '''
 
     name = 'limit'
+    readonly = True
 
     def getArgParser(self):
         pars = Cmd.getArgParser(self)
@@ -1869,6 +1862,7 @@ class UniqCmd(Cmd):
     '''
 
     name = 'uniq'
+    readonly = True
 
     def getArgParser(self):
         pars = Cmd.getArgParser(self)
@@ -1901,6 +1895,7 @@ class MaxCmd(Cmd):
     '''
 
     name = 'max'
+    readonly = True
 
     def getArgParser(self):
         pars = Cmd.getArgParser(self)
@@ -1947,6 +1942,7 @@ class MinCmd(Cmd):
         file:bytes +#foo.bar | min .seen
     '''
     name = 'min'
+    readonly = True
 
     def getArgParser(self):
         pars = Cmd.getArgParser(self)
@@ -2007,7 +2003,6 @@ class DelNodeCmd(Cmd):
                 mesg = '--force requires admin privs.'
                 raise s_exc.AuthDeny(mesg=mesg)
 
-        i = 0
         async for node, path in genr:
 
             # make sure we can delete the tags...
@@ -2018,10 +2013,7 @@ class DelNodeCmd(Cmd):
 
             await node.delete(force=self.opts.force)
 
-            i += 1
-            # Yield to other tasks occasionally
-            if not i % 1000:
-                await asyncio.sleep(0)
+            await asyncio.sleep(0)
 
         # a bit odd, but we need to be detected as a generator
         if False:
@@ -2176,6 +2168,7 @@ class SpinCmd(Cmd):
 
     '''
     name = 'spin'
+    readonly = True
 
     async def execStormCmd(self, runt, genr):
 
@@ -2196,6 +2189,7 @@ class CountCmd(Cmd):
 
     '''
     name = 'count'
+    readonly = True
 
     async def execStormCmd(self, runt, genr):
 
@@ -2216,6 +2210,7 @@ class IdenCmd(Cmd):
         iden b25bc9eec7e159dce879f9ec85fb791f83b505ac55b346fcb64c3c51e98d1175 | count
     '''
     name = 'iden'
+    readonly = True
 
     def getArgParser(self):
         pars = Cmd.getArgParser(self)
@@ -2232,15 +2227,19 @@ class IdenCmd(Cmd):
             try:
                 buid = s_common.uhex(iden)
             except Exception:
+                await asyncio.sleep(0)
                 await runt.warn(f'Failed to decode iden: [{iden}]')
                 continue
             if len(buid) != 32:
+                await asyncio.sleep(0)
                 await runt.warn(f'iden must be 32 bytes [{iden}]')
                 continue
 
             node = await runt.snap.getNodeByBuid(buid)
-            if node is not None:
-                yield node, runt.initPath(node)
+            if node is None:
+                await asyncio.sleep(0)
+                continue
+            yield node, runt.initPath(node)
 
 class SleepCmd(Cmd):
     '''
@@ -2254,6 +2253,7 @@ class SleepCmd(Cmd):
 
     '''
     name = 'sleep'
+    readonly = True
 
     async def execStormCmd(self, runt, genr):
         async for item in genr:
@@ -2333,10 +2333,10 @@ class GraphCmd(Cmd):
             rules['edges'] = False
 
         for pivo in self.opts.pivot:
-            rules['pivots'].append(pivo[1:-1])
+            rules['pivots'].append(pivo)
 
         for filt in self.opts.filter:
-            rules['filters'].append(filt[1:-1])
+            rules['filters'].append(filt)
 
         for name, pivo in self.opts.form_pivot:
 
@@ -2345,7 +2345,7 @@ class GraphCmd(Cmd):
                 formrule = {'pivots': [], 'filters': []}
                 rules['forms'][name] = formrule
 
-            formrule['pivots'].append(pivo[1:-1])
+            formrule['pivots'].append(pivo)
 
         for name, filt in self.opts.form_filter:
 
@@ -2354,7 +2354,7 @@ class GraphCmd(Cmd):
                 formrule = {'pivots': [], 'filters': []}
                 rules['forms'][name] = formrule
 
-            formrule['filters'].append(filt[1:-1])
+            formrule['filters'].append(filt)
 
         subg = s_ast.SubGraph(rules)
 
@@ -2377,6 +2377,7 @@ class TeeCmd(Cmd):
 
     '''
     name = 'tee'
+    readonly = True
 
     def getArgParser(self):
         pars = Cmd.getArgParser(self)
@@ -2395,25 +2396,29 @@ class TeeCmd(Cmd):
             raise s_exc.StormRuntimeError(mesg='Tee command must take at least one query as input.',
                                           name=self.name)
 
-        hasnodes = False
-        async for node, path in genr:  # type: s_node.Node, s_node.Path
-            hasnodes = True
-            for text in self.opts.query:
-                text = text[1:-1]
-                # This does update path with any vars set in the last npath (node.storm behavior)
-                async for nnode, npath in node.storm(text, user=runt.user, path=path):
-                    yield nnode, npath
+        with contextlib.ExitStack() as stack:
 
-            if self.opts.join:
-                yield node, path
-
-        if not hasnodes:
+            runts = []
             for text in self.opts.query:
-                text = text[1:-1]
                 query = await runt.getStormQuery(text)
-                subr = await runt.getScopeRuntime(query)
-                async for nnode, npath in subr.iterStormQuery(query):
-                    yield nnode, npath
+                subr = stack.enter_context(runt.getSubRuntime(query))
+                runts.append(subr)
+
+            item = None
+            async for item in genr:
+
+                for subr in runts:
+                    subg = s_common.agen(item)
+                    async for subitem in subr.execute(genr=subg):
+                        yield subitem
+
+                if self.opts.join:
+                    yield item
+
+            if item is None and self.runtsafe:
+                for subr in runts:
+                    async for subitem in subr.execute():
+                        yield subitem
 
 class TreeCmd(Cmd):
     '''
@@ -2425,6 +2430,7 @@ class TreeCmd(Cmd):
         inet:fqdn=www.vertex.link | tree { :domain -> inet:fqdn }
     '''
     name = 'tree'
+    readonly = True
 
     def getArgParser(self):
         pars = Cmd.getArgParser(self)
@@ -2433,13 +2439,13 @@ class TreeCmd(Cmd):
 
     async def execStormCmd(self, runt, genr):
 
-        text = self.opts.query[1:-1]
+        text = self.opts.query
 
         async def recurse(node, path):
 
             yield node, path
 
-            async for nnode, npath in node.storm(text, user=runt.user, path=path):
+            async for nnode, npath in node.storm(runt, text, path=path):
                 async for item in recurse(nnode, npath):
                     yield item
 
@@ -2469,6 +2475,9 @@ class ScrapeCmd(Cmd):
 
         # Scrape properties inbound nodes and yield newly scraped nodes.
         inet:search:query | scrape --yield
+
+        # Skip re-fanging text before scraping.
+        inet:search:query | scrape --skiprefang
     '''
 
     name = 'scrape'
@@ -2480,6 +2489,8 @@ class ScrapeCmd(Cmd):
                           help='Create refs light edges to any scraped nodes from the input node')
         pars.add_argument('--yield', dest='doyield', default=False, action='store_true',
                           help='Include newly scraped nodes in the output')
+        pars.add_argument('--skiprefang', dest='dorefang', default=True, action='store_false',
+                          help='Do not remove de-fanging from text before scraping')
         pars.add_argument('values', nargs='*',
                           help='Specific relative properties or variables to scrape')
         return pars
@@ -2497,7 +2508,7 @@ class ScrapeCmd(Cmd):
                 text = str(await s_stormtypes.toprim(item))
 
                 try:
-                    for form, valu in s_scrape.scrape(text):
+                    for form, valu in s_scrape.scrape(text, refang=self.opts.dorefang):
                         addnode = await runt.snap.addNode(form, valu)
                         if self.opts.doyield:
                             yield addnode, runt.initPath(addnode)
@@ -2522,7 +2533,7 @@ class ScrapeCmd(Cmd):
 
                 text = str(text)
 
-                for form, valu in s_scrape.scrape(text):
+                for form, valu in s_scrape.scrape(text, refang=self.opts.dorefang):
 
                     try:
                         nnode = await node.snap.addNode(form, valu)
@@ -2562,6 +2573,7 @@ class SpliceListCmd(Cmd):
     '''
 
     name = 'splice.list'
+    readonly = True
 
     def getArgParser(self):
         pars = Cmd.getArgParser(self)
@@ -2847,3 +2859,131 @@ class SpliceUndoCmd(Cmd):
             # Yield to other tasks occasionally
             if not i % 1000:
                 await asyncio.sleep(0)
+
+class LiftByVerb(Cmd):
+    '''
+    Lift nodes from the current view by an light edge verb.
+
+    Examples:
+
+        # Lift all the n1 nodes for the light edge "foo"
+        lift.byverb "foo"
+
+        # Lift all the n2 nodes for the light edge "foo"
+        lift.byverb --n2 "foo"
+
+    Notes:
+
+        Only a single instance of a node will be yielded from this command
+        when that node is lifted via the light edge membership.
+    '''
+    name = 'lift.byverb'
+
+    def getArgParser(self):
+        pars = Cmd.getArgParser(self)
+        pars.add_argument('verb', type=str, required=True,
+                          help='The edge verb to lift nodes by.')
+        pars.add_argument('--n2', action='store_true', default=False,
+                          help='Lift by the N2 value instead of N1 value.')
+        return pars
+
+    async def iterEdgeNodes(self, verb, idenset, n2=False):
+        if n2:
+            async for (_, _, n2) in self.runt.snap.view.getEdges(verb):
+                if n2 in idenset:
+                    continue
+                await idenset.add(n2)
+                node = await self.runt.snap.getNodeByBuid(s_common.uhex(n2))
+                if node:
+                    yield node
+        else:
+            async for (n1, _, _) in self.runt.snap.view.getEdges(verb):
+                if n1 in idenset:
+                    continue
+                await idenset.add(n1)
+                node = await self.runt.snap.getNodeByBuid(s_common.uhex(n1))
+                if node:
+                    yield node
+
+    async def execStormCmd(self, runt, genr):
+
+        async with await s_spooled.Set.anit(dirn=self.runt.snap.core.dirn) as idenset:
+
+            if self.runtsafe:
+                verb = await s_stormtypes.tostr(self.opts.verb)
+                n2 = self.opts.n2
+
+                async for x in genr:
+                    yield x
+
+                async for node in self.iterEdgeNodes(verb, idenset, n2):
+                    yield node, runt.initPath(node)
+
+            else:
+                async for _node, _path in genr:
+                    verb = await s_stormtypes.tostr(self.opts.verb)
+                    n2 = self.opts.n2
+
+                    yield _node, _path
+
+                    async for node in self.iterEdgeNodes(verb, idenset, n2):
+                        yield node, _path.fork(node)
+
+class EdgesDelCmd(Cmd):
+    '''
+    Bulk delete light edges from input nodes.
+
+    Examples:
+
+        # Delete all "foo" light edges from an inet:ipv4
+        inet:ipv4=1.2.3.4 | edges.del foo
+
+        # Delete light edges with any verb from a node
+        inet:ipv4=1.2.3.4 | edges.del *
+
+        # Delete all "foo" light edges to an inet:ipv4
+        inet:ipv4=1.2.3.4 | edges.del foo --n2
+    '''
+    name = 'edges.del'
+
+    def getArgParser(self):
+        pars = Cmd.getArgParser(self)
+        pars.add_argument('verb', type=str, help='The verb of light edges to delete.')
+
+        pars.add_argument('--n2', action='store_true', default=False,
+                          help='Delete light edges where input node is N2 instead of N1.')
+        return pars
+
+    async def delEdges(self, node, verb, n2=False):
+        if n2:
+            n2iden = node.iden()
+            async for (v, n1iden) in node.iterEdgesN2(verb):
+                n1 = await self.runt.snap.getNodeByBuid(s_common.uhex(n1iden))
+                await n1.delEdge(v, n2iden)
+        else:
+            async for (v, n2iden) in node.iterEdgesN1(verb):
+                await node.delEdge(v, n2iden)
+
+    async def execStormCmd(self, runt, genr):
+
+        if self.runtsafe:
+            n2 = self.opts.n2
+            verb = await s_stormtypes.tostr(self.opts.verb)
+
+            if verb == '*':
+                verb = None
+
+            async for node, path in genr:
+                await self.delEdges(node, verb, n2)
+                yield node, path
+
+        else:
+            async for node, path in genr:
+                n2 = self.opts.n2
+                verb = await s_stormtypes.tostr(self.opts.verb)
+
+                if verb == '*':
+                    verb = None
+
+                await self.delEdges(node, verb, n2)
+                yield node, path
