@@ -63,7 +63,7 @@ class View(s_nexus.Pusher):  # type: ignore
             try:
                 self.triggers.load(tdef)
 
-            except asyncio.CancelledError:
+            except asyncio.CancelledError:  # pragma: no cover  TODO:  remove once >= py 3.8 only
                 raise
 
             except Exception:
@@ -97,11 +97,11 @@ class View(s_nexus.Pusher):  # type: ignore
     def isafork(self):
         return self.parent is not None
 
-    def pack(self):
+    async def pack(self):
         d = {'iden': self.iden}
         d.update(self.info.pack())
 
-        layrinfo = [lyr.pack() for lyr in self.layers]
+        layrinfo = [await lyr.pack() for lyr in self.layers]
         d['layers'] = layrinfo
 
         triginfo = [t.pack() for _, t in self.triggers.list()]
@@ -138,6 +138,8 @@ class View(s_nexus.Pusher):  # type: ignore
 
                 async for edge in layr.getEdges(verb=verb):
 
+                    await asyncio.sleep(0)
+
                     if edge in eset:
                         continue
 
@@ -196,7 +198,6 @@ class View(s_nexus.Pusher):  # type: ignore
             ((str,dict)): Storm messages.
         '''
         opts = self.core._initStormOpts(opts)
-
         user = self.core._userFromOpts(opts)
 
         MSG_QUEUE_SIZE = 1000
@@ -440,11 +441,9 @@ class View(s_nexus.Pusher):  # type: ignore
 
         async with await self.parent.snap(user=user) as snap:
 
-            with snap.getStormRuntime(user=user):
-                meta = await snap.getSnapMeta()
-
-                async for nodeedits in fromlayr.iterLayerNodeEdits():
-                    await parentlayr.storNodeEditsNoLift([nodeedits], meta)
+            meta = await snap.getSnapMeta()
+            async for nodeedits in fromlayr.iterLayerNodeEdits():
+                await parentlayr.storNodeEditsNoLift([nodeedits], meta)
 
         await fromlayr.truncate()
 
@@ -513,63 +512,84 @@ class View(s_nexus.Pusher):  # type: ignore
                     if splicecount % 1000 == 0:
                         await asyncio.sleep(0)
 
-    async def runTagAdd(self, node, tag, valu):
+    async def runTagAdd(self, node, tag, valu, view=None):
 
         # Run the non-glob callbacks, then the glob callbacks
         funcs = itertools.chain(self.core.ontagadds.get(tag, ()), (x[1] for x in self.core.ontagaddglobs.get(tag)))
         for func in funcs:
             try:
                 await s_coro.ornot(func, node, tag, valu)
-            except asyncio.CancelledError:
+            except asyncio.CancelledError:  # pragma: no cover  TODO:  remove once >= py 3.8 only
                 raise
             except Exception:
                 logger.exception('onTagAdd Error')
 
-        # Run any trigger handlers
-        await self.triggers.runTagAdd(node, tag)
+        if view is None:
+            view = self.iden
 
-    async def runTagDel(self, node, tag, valu):
+        # Run any trigger handlers
+        await self.triggers.runTagAdd(node, tag, view=view)
+
+        if self.parent is not None:
+            await self.parent.runTagAdd(node, tag, valu, view=view)
+
+    async def runTagDel(self, node, tag, valu, view=None):
 
         funcs = itertools.chain(self.core.ontagdels.get(tag, ()), (x[1] for x in self.core.ontagdelglobs.get(tag)))
         for func in funcs:
             try:
                 await s_coro.ornot(func, node, tag, valu)
-            except asyncio.CancelledError:
+            except asyncio.CancelledError:  # pragma: no cover  TODO:  remove once >= py 3.8 only
                 raise
             except Exception:
                 logger.exception('onTagDel Error')
 
-        await self.triggers.runTagDel(node, tag)
+        if view is None:
+            view = self.iden
 
-    async def runNodeAdd(self, node):
+        await self.triggers.runTagDel(node, tag, view=view)
+
+        if self.parent is not None:
+            await self.parent.runTagDel(node, tag, valu, view=view)
+
+    async def runNodeAdd(self, node, view=None):
         if not node.snap.trigson:
             return
 
-        await self.triggers.runNodeAdd(node)
+        if view is None:
+            view = self.iden
+
+        await self.triggers.runNodeAdd(node, view=view)
 
         if self.parent is not None:
-            await self.parent.runNodeAdd(node)
+            await self.parent.runNodeAdd(node, view=view)
 
-    async def runNodeDel(self, node):
+    async def runNodeDel(self, node, view=None):
         if not node.snap.trigson:
             return
 
-        await self.triggers.runNodeDel(node)
+        if view is None:
+            view = self.iden
+
+        await self.triggers.runNodeDel(node, view=view)
 
         if self.parent is not None:
-            await self.parent.runNodeDel(node)
+            await self.parent.runNodeDel(node, view=view)
 
-    async def runPropSet(self, node, prop, oldv):
+    async def runPropSet(self, node, prop, oldv, view=None):
         '''
         Handle when a prop set trigger event fired
         '''
         if not node.snap.trigson:
             return
 
-        await self.triggers.runPropSet(node, prop, oldv)
+        if view is None:
+            view = self.iden
+
+        await self.triggers.runPropSet(node, prop, oldv, view=view)
 
         if self.parent is not None:
-            await self.parent.runPropSet(node, prop, oldv)
+            await self.parent.runPropSet(node, prop, oldv, view=view)
 
     async def addTrigger(self, tdef):
         '''
