@@ -168,6 +168,7 @@ class Dist(s_types.Int):
         s_types.Int.postTypeInit(self)
         self.setNormFunc(int, self._normPyInt)
         self.setNormFunc(str, self._normPyStr)
+        self.baseoff = self.opts.get('baseoff', 0)
 
     def _normPyInt(self, valu):
         return valu, {}
@@ -187,16 +188,33 @@ class Dist(s_types.Int):
             raise s_exc.BadTypeValu(valu=text, name=self.name,
                                     mesg='invalid/unknown dist unit: %s' % (unit,))
 
-        return int(valu * mult), {}
+        norm = int(valu * mult) + self.baseoff
+        if norm < 0:
+            mesg = 'A geo:dist may not be negative.'
+            raise s_exc.BadTypeValu(mesg=mesg, name=self.name, valu=text)
+
+        return norm, {}
 
     def repr(self, norm):
 
-        for base, unit in distrepr:
-            if norm >= base:
-                size = norm / base
-                return '%s %s' % (size, unit)
+        valu = norm - self.baseoff
 
-        return '%d mm' % (norm,)
+        text = None
+
+        absv = abs(valu)
+        for base, unit in distrepr:
+            if absv >= base:
+                size = absv / base
+                text = '%s %s' % (size, unit)
+                break
+
+        if text is None:
+            text = '%d mm' % (absv,)
+
+        if valu < 0:
+            text = f'-{text}'
+
+        return text
 
 class LatLong(s_types.Type):
 
@@ -261,10 +279,10 @@ class GeoModule(s_module.CoreModule):
 
                 'ctors': (
                     ('geo:dist', 'synapse.models.geospace.Dist', {}, {
-                        'doc': 'A geographic distance (base unit is mm)', 'ex': '10 km'
+                        'doc': 'A geographic distance (base unit is mm).', 'ex': '10 km'
                     }),
                     ('geo:latlong', 'synapse.models.geospace.LatLong', {}, {
-                        'doc': 'A Lat/Long string specifying a point on Earth',
+                        'doc': 'A Lat/Long string specifying a point on Earth.',
                         'ex': '-12.45,56.78'
                     }),
                 ),
@@ -297,6 +315,9 @@ class GeoModule(s_module.CoreModule):
                                                 ('ymax', 'geo:latitude'))}), {
                         'doc': 'A geospatial bounding box in (xmin, xmax, ymin, ymax) format.',
                     }),
+                    ('geo:altitude', ('geo:dist', {'baseoff': 6371008800}), {
+                        'doc': 'A negative or positive offset from Mean Sea Level (6,371.0088km from Earths core).'
+                    }),
                 ),
 
                 'forms': (
@@ -304,7 +325,7 @@ class GeoModule(s_module.CoreModule):
                     ('geo:nloc', {}, (
 
                         ('ndef', ('ndef', {}), {'ro': True,
-                            'doc': 'The node with location in geo/time'}),
+                            'doc': 'The node with location in geospace and time.'}),
 
                         ('ndef:form', ('str', {}), {'ro': True,
                             'doc': 'The form of node referenced by the ndef.'}),
@@ -313,7 +334,7 @@ class GeoModule(s_module.CoreModule):
                             'doc': 'The latitude/longitude the node was observed.'}),
 
                         ('time', ('time', {}), {'ro': True,
-                            'doc': 'The time the node was observed at location'}),
+                            'doc': 'The time the node was observed at location.'}),
 
                         ('place', ('geo:place', {}), {
                             'doc': 'The place corresponding to the latlong property.'}),
