@@ -1,5 +1,15 @@
 import synapse.lib.module as s_module
 
+contracttypes = (
+    'nda',
+    'other',
+    'grant',
+    'treaty',
+    'purchase',
+    'indemnity',
+    'partnership',
+)
+
 class OuModule(s_module.CoreModule):
     def getModelDefs(self):
         modl = {
@@ -15,11 +25,21 @@ class OuModule(s_module.CoreModule):
                 ('ou:org', ('guid', {}), {
                     'doc': 'A GUID for a human organization such as a company or military unit.',
                 }),
+                ('ou:contract', ('guid', {}), {
+                    'doc': 'An contract between multiple entities.',
+                }),
+                ('ou:contract:type', ('str', {'enum': contracttypes}), {
+                    'doc': 'A pre-defined set of contract types.',
+                }),
+                ('ou:industry', ('guid', {}), {
+                    'doc': 'An industry classification type.',
+                }),
                 ('ou:alias', ('str', {'lower': True, 'regex': r'^[0-9a-z_]+$'}), {
                     'doc': 'An alias for the org GUID.',
                     'ex': 'vertexproject',
                 }),
                 ('ou:hasalias', ('comp', {'fields': (('org', 'ou:org'), ('alias', 'ou:alias'))}), {
+                    'deprecated': True,
                     'doc': 'The knowledge that an organization has an alias.',
                 }),
                 ('ou:orgnet4', ('comp', {'fields': (('org', 'ou:org'), ('net', 'inet:net4'))}), {
@@ -76,8 +96,56 @@ class OuModule(s_module.CoreModule):
                 ('ou:campaign', ('guid', {}), {
                     'doc': 'Represents an orgs activity in pursuit of a goal.',
                 }),
+                ('ou:id:type', ('guid', {}), {
+                    'doc': 'A type of id number issued by an org.',
+                }),
+                ('ou:id:value', ('str', {'strip': True}), {
+                    'doc': 'The value of an org:id:number.',
+                }),
+                ('ou:id:number', ('comp', {'fields': (('type', 'ou:id:type'), ('value', 'ou:id:value'))}), {
+                    'doc': 'A unique id number issued by a specific organization.',
+                }),
+                ('ou:id:update', ('guid', {}), {
+                    'doc': 'A status update to an org:id:number.',
+                }),
             ),
             'forms': (
+                ('ou:id:type', {}, (
+                    ('org', ('ou:org', {}), {
+                        'doc': 'The org which issues id numbers of this type.',
+                    }),
+                    ('name', ('str', {}), {
+                        'doc': 'The friendly name of the id number type.',
+                    }),
+                )),
+                ('ou:id:number', {}, (
+                    ('type', ('ou:id:type', {}), {
+                        'doc': 'The type of org id',
+                    }),
+                    ('value', ('ou:id:value', {}), {
+                        'doc': 'The type of org id',
+                    }),
+                    ('status', ('str', {'lower': True, 'strip': True}), {
+                        'doc': 'A freeform status such as valid, suspended, expired.',
+                    }),
+                    ('issued', ('time', {}), {
+                        'doc': 'The time at which the org issued the ID number.',
+                    }),
+                    ('expires', ('time', {}), {
+                        'doc': 'The time at which the ID number expires.',
+                    }),
+                )),
+                ('ou:id:update', {}, (
+                    ('number', ('ou:id:number', {}), {
+                        'doc': 'The id number that was updated.',
+                    }),
+                    ('status', ('str', {'strip': True, 'lower': True}), {
+                        'doc': 'The updated status of the id number.',
+                    }),
+                    ('time', ('time', {}), {
+                        'doc': 'The date/time that the id number was updated.',
+                    }),
+                )),
                 ('ou:goal', {}, (
                     ('name', ('str', {}), {
                         'doc': 'A terse name for the goal.',
@@ -87,6 +155,7 @@ class OuModule(s_module.CoreModule):
                     }),
                     ('desc', ('str', {}), {
                         'doc': 'A description of the goal.',
+                        'disp': {'hint': 'text'},
                     }),
                     ('prev', ('ou:goal', {}), {
                         'doc': 'The previous/parent goal in a list or hierarchy.',
@@ -124,6 +193,7 @@ class OuModule(s_module.CoreModule):
                     }),
                     ('desc', ('str', {}), {
                         'doc': 'A description of the campaign.',
+                        'disp': {'hint': 'text'},
                     }),
                 )),
                 ('ou:org', {}, (
@@ -133,6 +203,9 @@ class OuModule(s_module.CoreModule):
                     ('name', ('ou:name', {}), {
                         'doc': 'The localized name of an organization.',
                     }),
+                    ('desc', ('str', {}), {
+                        'doc': 'A description of the org.',
+                    }),
                     ('names', ('array', {'type': 'ou:name'}), {
                        'doc': 'A list of alternate names for the organization.',
                     }),
@@ -143,11 +216,16 @@ class OuModule(s_module.CoreModule):
                         'doc': 'The primary phone number for the organization.',
                     }),
                     ('sic', ('ou:sic', {}), {
+                        'deprecated': True,
                         'doc': 'The Standard Industrial Classification code for the organization.',
                     }),
                     ('naics', ('ou:naics', {}), {
+                        'deprecated': True,
                         'doc': 'The North American Industry Classification System code for the organization.',
                     }),
+                    ('industries', ('array', {'type': 'ou:industry'}), {
+                        'doc': 'The industries associated with the org.',
+                    }),
                     ('us:cage', ('gov:us:cage', {}), {
                         'doc': 'The Commercial and Government Entity (CAGE) code for the organization.',
                     }),
@@ -164,6 +242,15 @@ class OuModule(s_module.CoreModule):
                     ('orgchart', ('ou:position', {}), {
                         'doc': 'The root node for an orgchart made up ou:position nodes.',
                     }),
+                    ('hq', ('ps:contact', {}), {
+                        'doc': 'A collection of contact information for the "main office" of an org.',
+                    }),
+                    ('locations', ('array', {'type': 'ps:contact'}), {
+                        'doc': 'An array of contacts for facilities operated by the org.',
+                    }),
+                    ('dns:mx', ('array', {'type': 'inet:fqdn'}), {
+                        'doc': 'An array of MX domains used by email addresses issued by the org.',
+                    }),
                 )),
                 ('ou:position', {}, (
                     ('org', ('ou:org', {}), {
@@ -180,6 +267,44 @@ class OuModule(s_module.CoreModule):
                     }),
                 )),
                 ('ou:name', {}, ()),
+                ('ou:contract', {}, (
+                    ('title', ('str', {}), {
+                        'doc': 'A terse title for the contract.'}),
+                    ('types', ('array', {'type': 'ou:contract:type', 'uniq': True, 'split': ','}), {
+                        'doc': 'A list of types that apply to the contract.'}),
+                    ('sponsor', ('ps:contact', {}), {
+                        'doc': 'The contract sponsor.'}),
+                    ('parties', ('array', {'type': 'ps:contact', 'uniq': True}), {
+                        'doc': 'The non-sponsor entities bound by the contract.'}),
+                    ('document', ('file:bytes', {}), {
+                        'doc': 'The best/current contract document.'}),
+                    ('signed', ('time', {}), {
+                        'doc': 'The date that the contract signing was complete.'}),
+                    ('begins', ('time', {}), {
+                        'doc': 'The date that the contract goes into effect.'}),
+                    ('expires', ('time', {}), {
+                        'doc': 'The date that the contract expires.'}),
+                    ('completed', ('time', {}), {
+                        'doc': 'The date that the contract was completed.'}),
+                    ('terminated', ('time', {}), {
+                        'doc': 'The date that the contract was terminated.'}),
+                    ('award:price', ('econ:currency', {}), {
+                        'doc': 'The value of the contract at time of award.'}),
+                    ('purchase', ('econ:purchase', {}), {
+                        'doc': 'Purchase details of the contract.'}),
+                    ('requirements', ('array', {'type': 'ou:goal', 'uniq': True}), {
+                        'doc': 'The requirements levied upon the parties.'}),
+                )),
+                ('ou:industry', {}, (
+                    ('name', ('str', {'lower': True, 'strip': True}), {
+                        'doc': 'A terse name for the industry.'}),
+                    ('subs', ('array', {'type': 'ou:industry', 'uniq': True, 'split': ','}), {
+                        'doc': 'An array of sub-industries.'}),
+                    ('sic', ('array', {'type': 'ou:sic', 'uniq': True, 'split': ','}), {
+                        'doc': 'An array of SIC codes that map to the industry.'}),
+                    ('naics', ('array', {'type': 'ou:naics', 'uniq': True, 'split': ','}), {
+                        'doc': 'An array of NAICS codes that map to the industry.'}),
+                )),
                 ('ou:hasalias', {}, (
                     ('org', ('ou:org', {}), {
                         'ro': True,
@@ -316,6 +441,7 @@ class OuModule(s_module.CoreModule):
                     ('desc', ('str', {'lower': True}), {
                         'doc': 'A description of the conference.',
                         'ex': 'annual cybersecurity conference',
+                        'disp': {'hint': 'text'},
                     }),
                     ('base', ('str', {'lower': True, 'strip': True}), {
                         'doc': 'The base name which is shared by all conference instances.',
@@ -374,6 +500,7 @@ class OuModule(s_module.CoreModule):
                     ('desc', ('str', {'lower': True}), {
                         'doc': 'A description of the conference event.',
                         'ex': 'foobar conference networking dinner at ridge hotel',
+                        'disp': {'hint': 'text'},
                     }),
                     ('url', ('inet:url', ()), {
                         'doc': 'The inet:url node for the conference event website.',
