@@ -190,6 +190,21 @@ class PsModule(s_module.CoreModule):
                     ('phone:work', ('tel:phone', {}), {
                         'doc': 'The work phone number for this contact.',
                     }),
+                    ('id:number', ('ou:id:number', {}), {
+                        'doc': 'An ID number issued by an org and associated with this contact.',
+                    }),
+                    ('adid', ('it:adid', {}), {
+                        'doc': 'A Advertising ID associated with this contact.',
+                    }),
+                    ('imid', ('tel:mob:imid', {}), {
+                        'doc': 'An IMID associated with the contact.',
+                    }),
+                    ('imid:imei', ('tel:mob:imei', {}), {
+                        'doc': 'An IMEI associated with the contact.',
+                    }),
+                    ('imid:imsi', ('tel:mob:imsi', {}), {
+                        'doc': 'An IMSI associated with the contact.',
+                    }),
                 )),
             )
         }
