@@ -322,7 +322,7 @@ class LayerTest(s_t_utils.SynTest):
             splices = await alist(layr.splices(None, 10))
             spliceoffs = (splices[-1][0][0] + 1, 0, 0)
 
-            await core.addTagProp('risk', ('int', {'minval': 0, 'maxval': 100}), {'doc': 'risk score'})
+            await core.addTagProp('risk', ('int', {'min': 0, 'max': 100}), {'doc': 'risk score'})
 
             # Convert a node:add splice
             await core.nodes('[ test:str=foo ]')
@@ -661,35 +661,17 @@ class LayerTest(s_t_utils.SynTest):
             nodes = await core.nodes('inet:ipv4=1.2.3.4 [ +#foo.bar=2015 ]')
             self.eq((1325376000000, 1420070400001), nodes[0].getTag('foo.bar'))
 
-            nodeedits = [
-                (buid, None, (
-                    (s_layer.EDIT_PROP_SET, ('loc', 'us', None, s_layer.STOR_TYPE_LOC), ()),
-                )),
-            ]
-
-            nodeedits_out = await layr.storNodeEdits(nodeedits, {})
-            self.notin('loc', nodeedits_out[0][1]['props'])
-
-            nodeedits = [
-                (buid, None, (
-                    (s_layer.EDIT_TAG_SET, ('faz.baz', (None, None), (None, None)), ()),
-                )),
-            ]
-
-            nodeedits_out = await layr.storNodeEdits(nodeedits, {})
-            self.notin('faz.baz', nodeedits_out[0][1]['tags'])
-
     async def test_layer_nodeedits_created(self):
 
         async with self.getTestCore() as core:
 
             nodes = await core.nodes('[ test:int=1 :loc=us ]')
             created00 = nodes[0].get('.created')
+            self.nn(created00)
 
             layr = core.getLayer()
 
             editlist00 = [nes async for nes in layr.iterLayerNodeEdits()]
-
             await core.nodes('test:int=1 | delnode')
             self.len(0, await core.nodes('test:int'))
 
@@ -710,7 +692,7 @@ class LayerTest(s_t_utils.SynTest):
 
             # If meta is not specified .created gets populated to now
             await asyncio.sleep(0.01)
-            await layr.storNodeEdits(nexslist00, None)
+            await layr.storNodeEdits(nexslist00, {})
 
             nodes = await core.nodes('test:int')
             self.len(1, nodes)
@@ -818,6 +800,19 @@ class LayerTest(s_t_utils.SynTest):
                     for nodeedit in layr.nodeeditlog.sliceBack(lastoffs, 2):
                         self.eq(meta, nodeedit[1][1])
 
+                    async def waitForEdit():
+                        edit = (0, ('endofquery', 1), ())
+                        async for item in layr.syncNodeEdits(lastoffs):
+                            if item[1][0][1] == 'test:str' and edit in item[1][0][2]:
+                                return
+                            await asyncio.sleep(0)
+
+                    async def doEdit():
+                        await core1.nodes(f'sleep 1 | [ test:str=endofquery ]')
+
+                    task = core1.schedCoro(doEdit())
+                    await asyncio.wait_for(waitForEdit(), timeout=6)
+
     async def test_layer_form_by_buid(self):
 
         async with self.getTestCore() as core:
@@ -994,3 +989,20 @@ class LayerTest(s_t_utils.SynTest):
 
             readlayr = core.getLayer(readlayrinfo.get('iden'))
             self.true(readlayr.readonly)
+
+    async def test_layer_v3(self):
+
+        async with self.getRegrCore('2.0-layerv2tov3') as core:
+
+            nodes = await core.nodes('inet:ipv4=1.2.3.4')
+            self.len(1, nodes)
+            self.eq(nodes[0].ndef, ('inet:ipv4', 0x01020304))
+            self.eq(nodes[0].get('asn'), 33)
+            self.true(nodes[0].getTag('foo.bar'), (None, None))
+            self.true(nodes[0].getTagProp('foo.bar', 'confidence'), 22)
+
+            self.eq(10004, await core.count('.created'))
+            self.len(2, await core.nodes('syn:tag~=foo'))
+
+            for layr in core.layers.values():
+                self.eq(layr.layrvers, 3)
