@@ -30,7 +30,8 @@ def make_core(dirn, conf, queries, queue, event):
             await core.addTagProp('added', ('time', {}), {})
             for q in queries:
                 await core.nodes(q)
-            core.view.layers[0].layrslab.forcecommit()
+
+            await core.view.layers[0].layrslab.sync()
 
             spawninfo = await core.getSpawnInfo()
             queue.put(spawninfo)
@@ -538,6 +539,10 @@ class CoreSpawnTest(s_test.SynTest):
                 async with core.getLocalProxy() as prox:
                     opts = {'spawn': True}
 
+                    # Ensure the spawncore loaded the service
+                    coro = prox.storm('$lib.service.wait(real)', opts).list()
+                    msgs = await asyncio.wait_for(coro, 30)
+
                     msgs = await prox.storm('help', opts=opts).list()
                     self.stormIsInPrint('foobar', msgs)
 
