@@ -11,6 +11,17 @@ from synapse.tests.utils import alist
 
 class StormTest(s_t_utils.SynTest):
 
+    async def test_lib_storm_basics(self):
+        # a catch-all bucket for simple tests to avoid cortex construction
+        async with self.getTestCore() as core:
+
+            with self.raises(s_exc.NoSuchVar):
+                await core.nodes('inet:ipv4=$ipv4')
+
+            # test that runtsafe vars stay runtsafe
+            msgs = await core.stormlist('$foo=bar $lib.print($foo) if $node { $foo=$node.value() }')
+            self.stormIsInPrint('bar', msgs)
+
     async def test_storm_tree(self):
 
         async with self.getTestCore() as core:
@@ -231,20 +242,6 @@ class StormTest(s_t_utils.SynTest):
                 await self.agenlen(0, core.eval(q))
                 self.true(stream.wait(1))
 
-    async def test_storm_input(self):
-
-        async with self.getTestCore() as core:
-
-            async with await core.snap() as snap:
-
-                node = await snap.addNode('test:str', 'woot')
-                await s_common.aspin(node.storm('[ +#hehe ]'))
-
-                await self.agenlen(1, snap.eval('#hehe'))
-
-                await s_common.aspin(node.storm('[ -#hehe ]'))
-                await self.agenlen(0, snap.eval('#hehe'))
-
     async def test_minmax(self):
 
         async with self.getTestCore() as core:
@@ -357,6 +354,13 @@ class StormTest(s_t_utils.SynTest):
             self.len(1, nodes)
             self.eq(nodes[0].ndef, ('inet:ipv4', 0x06050403))
 
+            nodes = await core.nodes('$foo="6[.]5[.]4[.]3" | scrape $foo --yield')
+            self.len(1, nodes)
+            self.eq(nodes[0].ndef, ('inet:ipv4', 0x06050403))
+
+            nodes = await core.nodes('$foo="6[.]5[.]4[.]3" | scrape $foo --yield --skiprefang')
+            self.len(0, nodes)
+
             # per-node tests
 
             guid = s_common.guid()
@@ -592,7 +596,7 @@ class StormTest(s_t_utils.SynTest):
 
         async with self.getTestCoreAndProxy() as (core, prox):
 
-            await core.addTagProp('risk', ('int', {'minval': 0, 'maxval': 100}), {'doc': 'risk score'})
+            await core.addTagProp('risk', ('int', {'min': 0, 'max': 100}), {'doc': 'risk score'})
 
             visi = await prox.addUser('visi', passwd='secret')
 
@@ -935,3 +939,112 @@ class StormTest(s_t_utils.SynTest):
         self.none(pars.parse_args(['--ques', 'lolz', 'hehe']))
         helptext = '\n'.join(pars.mesgs)
         self.isin("Invalid value for type (<class 'int'>): lolz", helptext)
+
+    async def test_liftby_edge(self):
+        async with self.getTestCore() as core:
+
+            await core.nodes('[ test:str=test1 +(refs)> { [test:int=7] } ]')
+            await core.nodes('[ test:str=test1 +(refs)> { [test:int=8] } ]')
+            await core.nodes('[ test:str=test2 +(refs)> { [test:int=8] } ]')
+
+            nodes = await core.nodes('lift.byverb refs')
+            self.eq(sorted([n.ndef[1] for n in nodes]), ['test1', 'test2'])
+
+            nodes = await core.nodes('lift.byverb --n2 refs ')
+            self.eq(sorted([n.ndef[1] for n in nodes]), [7, 8])
+
+            nodes = await core.nodes('lift.byverb $v', {'vars': {'v': 'refs'}})
+            self.eq(sorted([n.ndef[1] for n in nodes]), ['test1', 'test2'])
+
+            q = '[(test:str=refs) (test:str=foo)] $v=$node.value() | lift.byverb $v'
+            nodes = await core.nodes(q)
+            self.len(4, nodes)
+            self.eq({n.ndef[1] for n in nodes},
+                    {'test1', 'test2', 'refs', 'foo'})
+
+    async def test_storm_nested_root(self):
+        async with self.getTestCore() as core:
+            self.eq(20, await core.callStorm('''
+            $foo = (100)
+            function x() {
+                function y() {
+                    function z() {
+                        $foo = (20)
+                    }
+                    $z()
+                }
+                $y()
+            }
+            $x()
+            return ($foo)
+            '''))
+
+    async def test_edges_del(self):
+        async with self.getTestCore() as core:
+
+            await core.nodes('[ test:str=test1 +(refs)> { [test:int=7 test:int=8] } ]')
+            await core.nodes('[ test:str=test1 +(seen)> { [test:int=7 test:int=8] } ]')
+
+            self.len(4, await core.nodes('test:str=test1 -(*)> *'))
+
+            await core.nodes('test:str=test1 | edges.del refs')
+            self.len(0, await core.nodes('test:str=test1 -(refs)> *'))
+            self.len(2, await core.nodes('test:str=test1 -(seen)> *'))
+
+            await core.nodes('test:str=test1 [ +(refs)> { [test:int=7 test:int=8] } ]')
+
+            self.len(4, await core.nodes('test:str=test1 -(*)> *'))
+
+            await core.nodes('test:str=test1 | edges.del *')
+            self.len(0, await core.nodes('test:str=test1 -(*)> *'))
+
+            # Test --n2
+            await core.nodes('test:str=test1 [ <(refs)+ { [test:int=7 test:int=8] } ]')
+            await core.nodes('test:str=test1 [ <(seen)+ { [test:int=7 test:int=8] } ]')
+
+            self.len(4, await core.nodes('test:str=test1 <(*)- *'))
+
+            await core.nodes('test:str=test1 | edges.del refs --n2')
+            self.len(0, await core.nodes('test:str=test1 <(refs)- *'))
+            self.len(2, await core.nodes('test:str=test1 <(seen)- *'))
+
+            await core.nodes('test:str=test1 [ <(refs)+ { [test:int=7 test:int=8] } ]')
+
+            self.len(4, await core.nodes('test:str=test1 <(*)- *'))
+
+            await core.nodes('test:str=test1 | edges.del * --n2')
+            self.len(0, await core.nodes('test:str=test1 <(*)- *'))
+
+            # Test non-runtsafe usage
+            await core.nodes('[ test:str=refs +(refs)> { [test:int=7 test:int=8] } ]')
+            await core.nodes('[ test:str=seen +(seen)> { [test:int=7 test:int=8] } ]')
+
+            self.len(2, await core.nodes('test:str=refs -(refs)> *'))
+            self.len(2, await core.nodes('test:str=seen -(seen)> *'))
+
+            await core.nodes('test:str=refs test:str=seen $v=$node.value() | edges.del $v')
+
+            self.len(0, await core.nodes('test:str=refs -(refs)> *'))
+            self.len(0, await core.nodes('test:str=seen -(seen)> *'))
+
+            await core.nodes('test:str=refs [ <(refs)+ { [test:int=7 test:int=8] } ]')
+            await core.nodes('test:str=seen [ <(seen)+ { [test:int=7 test:int=8] } ]')
+
+            self.len(2, await core.nodes('test:str=refs <(refs)- *'))
+            self.len(2, await core.nodes('test:str=seen <(seen)- *'))
+
+            await core.nodes('test:str=refs test:str=seen $v=$node.value() | edges.del $v --n2')
+
+            self.len(0, await core.nodes('test:str=refs <(refs)- *'))
+            self.len(0, await core.nodes('test:str=seen <(seen)- *'))
+
+            await core.nodes('test:str=refs [ <(refs)+ { [test:int=7 test:int=8] } ]')
+            await core.nodes('[ test:str=* <(seen)+ { [test:int=7 test:int=8] } ]')
+
+            self.len(2, await core.nodes('test:str=refs <(refs)- *'))
+            self.len(2, await core.nodes('test:str=* <(seen)- *'))
+
+            await core.nodes('test:str=refs test:str=* $v=$node.value() | edges.del $v --n2')
+
+            self.len(0, await core.nodes('test:str=refs <(refs)- *'))
+            self.len(0, await core.nodes('test:str=* <(seen)- *'))
