@@ -159,7 +159,7 @@ class RealService(s_stormsvc.StormSvc):
             'storm': '$lib.queue.add(vertex)',
         },
         'del': {
-            'storm': '$lib.queue.del(vertex)',
+            'storm': '$que=$lib.queue.get(vertex) $que.put(done)',
         },
     }
 
@@ -463,7 +463,7 @@ class StormSvcTest(s_test.SynTest):
                 curl = f'tcp://127.0.0.1:{port}/lift'
                 durl = f'tcp://127.0.0.1:{port}/dead'
 
-                async with await s_cortex.Cortex.anit(dirn) as core:
+                async with self.getTestCore(dirn=dirn) as core:
 
                     await core.nodes(f'service.add fake {lurl}')
                     iden = core.getStormSvcs()[0].iden
@@ -542,7 +542,61 @@ class StormSvcTest(s_test.SynTest):
                     self.stormIsInPrint(f'svciden={iden}', msgs)
                     self.stormIsInPrint('key=valu', msgs)
 
-                async with await s_cortex.Cortex.anit(dirn) as core:
+                    # Check some service related permissions
+                    user = await core.auth.addUser('user')
+
+                    # No permissions is a failure too!
+                    msgs = await core.stormlist('$svc=$lib.service.get(fake)', {'user': user.iden})
+                    self.stormIsInErr(f'must have permission service.get.{iden}', msgs)
+
+                    # Old permissions still wrk for now but cause warnings
+                    await user.addRule((True, ('service', 'get', 'fake')))
+                    msgs = await core.stormlist('$svc=$lib.service.get(fake)', {'user': user.iden})
+                    self.stormIsInWarn('service.get.<servicename> permissions are deprecated.', msgs)
+                    await user.delRule((True, ('service', 'get', 'fake')))
+
+                    # storm service permissions should use svcidens
+                    await user.addRule((True, ('service', 'get', iden)))
+                    msgs = await core.stormlist('$svc=$lib.service.get(fake) $lib.print($svc)', {'user': user.iden})
+                    self.stormIsInPrint('StormSvcClient', msgs)
+                    self.len(0, [m for m in msgs if m[0] == 'warn'])
+
+                    msgs = await core.stormlist(f'$svc=$lib.service.get({iden}) $lib.print($svc)', {'user': user.iden})
+                    self.stormIsInPrint('StormSvcClient', msgs)
+                    self.len(0, [m for m in msgs if m[0] == 'warn'])
+
+                    msgs = await core.stormlist(f'$svc=$lib.service.get(real) $lib.print($svc)', {'user': user.iden})
+                    self.stormIsInPrint('StormSvcClient', msgs)
+                    self.len(0, [m for m in msgs if m[0] == 'warn'])
+
+                    q = '$hasfoo=$lib.service.has($svc) if $hasfoo {$lib.print(yes)} else {$lib.print(no)}'
+                    msgs = await core.stormlist(q, {'vars': {'svc': 'foo'}})
+                    self.stormIsInPrint('no', msgs)
+                    msgs = await core.stormlist(q, {'vars': {'svc': 'real'}})
+                    self.stormIsInPrint('yes', msgs)
+                    msgs = await core.stormlist(q, {'vars': {'svc': 'fake'}})
+                    self.stormIsInPrint('yes', msgs)
+                    msgs = await core.stormlist(q, {'vars': {'svc': iden}})
+                    self.stormIsInPrint('yes', msgs)
+
+                    # Since there ws a chnage to how $lib.service.wait handles permissions, anyone that can
+                    # get a service can also wait for it, so ensure that those permissions still work.
+                    # lib.service.wait can still be called both ways (iden or name)
+                    msgs = await core.stormlist('$svc=$lib.service.wait(fake) $lib.print(yup)', {'user': user.iden})
+                    self.len(0, [m for m in msgs if m[0] == 'err'])
+                    self.stormIsInPrint('yup', msgs)
+
+                    msgs = await core.stormlist(f'$svc=$lib.service.wait({iden}) $lib.print(yup)', {'user': user.iden})
+                    self.len(0, [m for m in msgs if m[0] == 'err'])
+                    self.stormIsInPrint('yup', msgs)
+
+                    await user.delRule((True, ('service', 'get', iden)))
+                    await user.addRule((True, ('service', 'get')))
+                    msgs = await core.stormlist(f'$svc=$lib.service.wait({iden}) $lib.print(yup)', {'user': user.iden})
+                    self.len(0, [m for m in msgs if m[0] == 'err'])
+                    self.stormIsInPrint('yup', msgs)
+
+                async with self.getTestCore(dirn=dirn) as core:
 
                     nodes = await core.nodes('$lib.service.wait(fake)')
                     nodes = await core.nodes('[ inet:ipv4=6.6.6.6 ] | ohhai')
@@ -571,9 +625,10 @@ class StormSvcTest(s_test.SynTest):
                     # make sure stormcmd got deleted
                     self.none(core.getStormCmd('ohhai'))
 
-                    # ensure fini ran
-                    queue = core.multiqueue.list()
-                    self.len(0, queue)
+                    # ensure del event ran
+                    q = 'for ($o, $m) in $lib.queue.get(vertex).gets(wait=10) {return (($o, $m))}'
+                    retn = await core.callStorm(q)
+                    self.eq(retn, (0, 'done'))
 
                     # specifically call teardown
                     for svc in core.getStormSvcs():
@@ -585,7 +640,7 @@ class StormSvcTest(s_test.SynTest):
                     self.len(0, core.getStormSvcs())
                     # make sure all the dels ran, except for the BoomService (which should fail)
                     nodes = await core.nodes('inet:ipv4')
-                    ans = set(['1.2.3.4', '5.5.5.5', '6.6.6.6', '8.8.8.8', '123.123.123.123'])
+                    ans = {'1.2.3.4', '5.5.5.5', '6.6.6.6', '8.8.8.8', '123.123.123.123'}
                     reprs = set(map(lambda k: k.repr(), nodes))
                     self.eq(ans, reprs)
 
@@ -793,11 +848,11 @@ class StormSvcTest(s_test.SynTest):
 
                         # Make sure it got removed from both
                         self.none(core00.getStormCmd('ohhai'))
-                        queue = core00.multiqueue.list()
-                        self.len(0, queue)
-                        self.notin('foo.bar', core00.stormmods)
+                        q = 'for ($o, $m) in $lib.queue.get(vertex).gets(wait=10) {return (($o, $m))}'
+                        retn = await core00.callStorm(q)
+                        self.eq(retn, (0, 'done'))
 
                         self.none(core01.getStormCmd('ohhai'))
-                        queue = core01.multiqueue.list()
-                        self.len(0, queue)
-                        self.notin('foo.bar', core01.stormmods)
+                        q = 'for ($o, $m) in $lib.queue.get(vertex).gets(wait=10) {return (($o, $m))}'
+                        retn = await core01.callStorm(q)
+                        self.eq(retn, (0, 'done'))
