@@ -80,23 +80,23 @@ class CryptoModelTest(s_t_utils.SynTest):
                 # md5
                 node = await snap.addNode('hash:md5', TEST_MD5.upper())
                 self.eq(node.ndef, ('hash:md5', TEST_MD5))
-                await self.asyncraises(s_exc.BadPropValu, snap.addNode('hash:md5', TEST_SHA1))
+                await self.asyncraises(s_exc.BadTypeValu, snap.addNode('hash:md5', TEST_SHA1))
                 # sha1
                 node = await snap.addNode('hash:sha1', TEST_SHA1.upper())
                 self.eq(node.ndef, ('hash:sha1', TEST_SHA1))
-                await self.asyncraises(s_exc.BadPropValu, snap.addNode('hash:sha1', TEST_SHA256))
+                await self.asyncraises(s_exc.BadTypeValu, snap.addNode('hash:sha1', TEST_SHA256))
                 # sha256
                 node = await snap.addNode('hash:sha256', TEST_SHA256.upper())
                 self.eq(node.ndef, ('hash:sha256', TEST_SHA256))
-                await self.asyncraises(s_exc.BadPropValu, snap.addNode('hash:sha256', TEST_SHA384))
+                await self.asyncraises(s_exc.BadTypeValu, snap.addNode('hash:sha256', TEST_SHA384))
                 # sha384
                 node = await snap.addNode('hash:sha384', TEST_SHA384.upper())
                 self.eq(node.ndef, ('hash:sha384', TEST_SHA384))
-                await self.asyncraises(s_exc.BadPropValu, snap.addNode('hash:sha384', TEST_SHA512))
+                await self.asyncraises(s_exc.BadTypeValu, snap.addNode('hash:sha384', TEST_SHA512))
                 # sha512
                 node = await snap.addNode('hash:sha512', TEST_SHA512.upper())
                 self.eq(node.ndef, ('hash:sha512', TEST_SHA512))
-                await self.asyncraises(s_exc.BadPropValu, snap.addNode('hash:sha512', TEST_MD5))
+                await self.asyncraises(s_exc.BadTypeValu, snap.addNode('hash:sha512', TEST_MD5))
 
     async def test_form_rsakey(self):
         prop = 'rsa:key'
@@ -152,8 +152,8 @@ class CryptoModelTest(s_t_utils.SynTest):
                     :signature=ff00ff00
 
                     :ext:sans=((dns, vertex.link), (dns, "*.vertex.link"))
-                    :ext:crls = ((dns, http://vertex.link/crls))
-                    :crl:urls = ("http://vertex.link/crls")
+                    :ext:crls = ((dns, http://vertex.link/crls),)
+                    :crl:urls = ("http://vertex.link/crls",)
 
                     :identities:urls=(http://woot.com/1, http://woot.com/2)
                     :identities:fqdns=(vertex.link, woot.com)
