@@ -94,8 +94,8 @@ class TelcoModelTest(s_t_utils.SynTest):
                          'mac': '00:00:00:00:00:00',
                          'ipv4': '1.2.3.4',
                          'ipv6': '::1',
-                         'wifi:ssid': 'The Best SSID2',
-                         'wifi:bssid': '00:11:22:33:44:55',
+                         'wifi': ('The Best SSID2', '00:11:22:33:44:55'),
+                         'adid': 'someadid',
                          'aaid': 'somestr',
                          'idfa': 'someotherstr',
                          'name': 'Robert Grey',
@@ -121,8 +121,10 @@ class TelcoModelTest(s_t_utils.SynTest):
                 self.eq(node.get('mac'), '00:00:00:00:00:00')
                 self.eq(node.get('ipv4'), 0x01020304)
                 self.eq(node.get('ipv6'), '::1')
+                self.eq(node.get('wifi'), ('The Best SSID2', '00:11:22:33:44:55')),
                 self.eq(node.get('wifi:ssid'), 'The Best SSID2')
                 self.eq(node.get('wifi:bssid'), '00:11:22:33:44:55')
+                self.eq(node.get('adid'), 'someadid')
                 self.eq(node.get('aaid'), 'somestr')
                 self.eq(node.get('idfa'), 'someotherstr')
                 self.eq(node.get('name'), 'robert grey')
