@@ -2,7 +2,7 @@
 This contains the core test helper code used in Synapse.
 
 This gives the opportunity for third-party users of Synapse to test their
-code using some of the same of the same helpers used to test Synapse.
+code using some of the same helpers used to test Synapse.
 
 The core class, synapse.tests.utils.SynTest is a subclass of unittest.TestCase,
 with several wrapper functions to allow for easier calls to assert* functions,
@@ -173,6 +173,10 @@ testmodel = {
             ('hehe', 'test:int'),
             ('haha', 'test:lower'))
         }), {'doc': 'A fake comp type.'}),
+        ('test:compcomp', ('comp', {'fields': (
+            ('comp1', 'test:comp'),
+            ('comp2', 'test:comp'))
+        }), {}),
         ('test:complexcomp', ('comp', {'fields': (
             ('foo', 'test:int'),
             ('bar', ('str', {'lower': True}),),
@@ -222,13 +226,18 @@ testmodel = {
         ('test:type', {}, ()),
 
         ('test:comp', {}, (
-            ('hehe', ('test:int', {}), {'ro': 1}),
-            ('haha', ('test:lower', {}), {'ro': 1}),
+            ('hehe', ('test:int', {}), {'ro': True}),
+            ('haha', ('test:lower', {}), {'ro': True}),
+        )),
+
+        ('test:compcomp', {}, (
+            ('comp1', ('test:comp', {}), {}),
+            ('comp2', ('test:comp', {}), {}),
         )),
 
         ('test:complexcomp', {}, (
-            ('foo', ('test:int', {}), {'ro': 1}),
-            ('bar', ('str', {'lower': 1}), {'ro': 1})
+            ('foo', ('test:int', {}), {'ro': True}),
+            ('bar', ('str', {'lower': 1}), {'ro': True})
         )),
 
         ('test:int', {}, (
@@ -242,10 +251,10 @@ testmodel = {
         )),
 
         ('test:edge', {}, (
-            ('n1', ('ndef', {}), {'ro': 1}),
-            ('n1:form', ('str', {}), {'ro': 1}),
-            ('n2', ('ndef', {}), {'ro': 1}),
-            ('n2:form', ('str', {}), {'ro': 1}),
+            ('n1', ('ndef', {}), {'ro': True}),
+            ('n1:form', ('str', {}), {'ro': True}),
+            ('n2', ('ndef', {}), {'ro': True}),
+            ('n2:form', ('str', {}), {'ro': True}),
         )),
 
         ('test:guid', {}, (
@@ -295,7 +304,7 @@ testmodel = {
         )),
 
         ('test:ndef', {}, (
-            ('form', ('str', {}), {'ro': 1}),
+            ('form', ('str', {}), {'ro': True}),
         )),
 
         ('test:runt', {'runt': True}, (
